Crate character_traits_leadership_and_authority

Crate character_traits_leadership_and_authority 

Structs

LeadershipAndAuthorityIter
An iterator over the variants of LeadershipAndAuthority
LeadershipApproachIntrinsicDimensionRatings
LeadershipApproachIntrinsicDimensionRatingsBuilder
Builder for LeadershipApproachIntrinsicDimensionRatings.
LeadershipApproachIter
An iterator over the variants of LeadershipApproach
LeadershipDomainIntrinsicDimensionRatings
LeadershipDomainIntrinsicDimensionRatingsBuilder
Builder for LeadershipDomainIntrinsicDimensionRatings.
LeadershipDomainIter
An iterator over the variants of LeadershipDomain
LeadershipProfile
A compositional representation of leadership style that can resolve back to concrete LeadershipAndAuthority descriptor variants.
LeadershipProfileBuilder
Builder for LeadershipProfile.
LeadershipToneIntrinsicDimensionRatings
LeadershipToneIntrinsicDimensionRatingsBuilder
Builder for LeadershipToneIntrinsicDimensionRatings.
LeadershipToneIter
An iterator over the variants of LeadershipTone

Enums

LeadershipAndAuthority
LeadershipApproach
LeadershipApproachIntrinsicDimensionRatingsBuilderError
Error type for LeadershipApproachIntrinsicDimensionRatingsBuilder
LeadershipDomain
LeadershipDomainIntrinsicDimensionRatingsBuilderError
Error type for LeadershipDomainIntrinsicDimensionRatingsBuilder
LeadershipProfileBuildError
LeadershipProfileBuilderError
Error type for LeadershipProfileBuilder
LeadershipTone
LeadershipToneIntrinsicDimensionRatingsBuilderError
Error type for LeadershipToneIntrinsicDimensionRatingsBuilder

Functions

analyze_leadership_descriptor
Returns the compositional signature of a single LeadershipAndAuthority descriptor.
detect_approach
detect_domain
detect_tones
find_leadership_descriptors_for
Returns every descriptor matching approach, optionally domain, and whose tone‑set supersets required.